@@ -169,11 +169,10 @@ static int llgt_run_lcas_authz_and_lcmaps_mapping (gss_ctx_id_t context, char **
             llgt_logmsg(LOG_DEBUG, "Execution of LCAS successful.\n");
         }
 
-	/* Close the log file, if used/opened */
-	if (flog_lcas)	{
-	    fclose(flog_lcas);
-	    flog_lcas=NULL;
-	}
+	/* Flush the log file, if used/opened. Do not close yet, as we are going
+	 * to terminate later. */
+	if (flog_lcas)
+	    fflush(flog_lcas);
     }
 #endif
 
@@ -230,6 +229,19 @@ static int llgt_run_lcas_authz_and_lcmaps_mapping (gss_ctx_id_t context, char **
     retval = 0;
 
 finalize:
+#ifndef DISABLE_LCAS
+    if (do_run_lcas) {
+	/* Only now terminate and close down LCAS */
+	llgt_lcas_terminate(1);
+
+	/* Close the log file, if used/opened */
+	if (flog_lcas)	{
+	    fclose(flog_lcas);
+	    flog_lcas=NULL;
+	}
+    }
+#endif
+
     /* Close the log file, if used/opened */
     if (flog_lcmaps) {
         fclose(flog_lcmaps);
@@ -286,7 +298,7 @@ globus_result_t lcmaps_callout( va_list ap)
     rc = globus_module_activate(GLOBUS_GRIDMAP_CALLOUT_ERROR_MODULE);
     if(rc!=0) {
         llgt_logmsg(LOG_ERR, "Error activating Globus GRIDMAP CALLOUT ERROR MODULE");
-        result = GLOBUS_FAILURE;
+        result = (globus_result_t)GLOBUS_FAILURE;
         goto llgt_finalize;
     }
 
@@ -338,7 +350,7 @@ globus_result_t lcmaps_callout( va_list ap)
 	    /* Reset failed local identity */
 	    free(local_identity);
 	    local_identity=NULL;
-	    result=GLOBUS_FAILURE;
+	    result=(globus_result_t)GLOBUS_FAILURE;
 	    goto llgt_finalize;
 	}
 	/* Cached result does not match desired identity */
@@ -355,14 +367,14 @@ globus_result_t lcmaps_callout( va_list ap)
     rc = globus_module_activate(GLOBUS_GSI_GSS_ASSIST_MODULE);
     if(rc!=0) {
         llgt_logmsg(LOG_ERR, "Error activating Globus GSS ASSIST MODULE");
-        result = GLOBUS_FAILURE;
+        result = (globus_result_t)GLOBUS_FAILURE;
         goto llgt_finalize;
     }
 
     rc = globus_module_activate(GLOBUS_GSI_GSSAPI_MODULE);
     if(rc!=0) {
         llgt_logmsg(LOG_ERR, "Error activating Globus GSSAPI MODULE");
-        result = GLOBUS_FAILURE;
+        result = (globus_result_t)GLOBUS_FAILURE;
         goto llgt_finalize;
     }
 
@@ -428,7 +440,7 @@ globus_result_t lcmaps_callout( va_list ap)
      *************************/
     if (llgt_run_lcas_authz_and_lcmaps_mapping (context, &local_identity)) {
         /* llgt_logmsg(LOG_ERR, "Failure in Authorization and Mapping"); */
-        result = GLOBUS_FAILURE;
+        result = (globus_result_t)GLOBUS_FAILURE;
         goto llgt_finalize;
     }
 
